#Shawn Leroux. Revised April 5, 2015. 
#This is the corresponding R code for all analyses in Leroux et al. [in press] Legislative correlates of the size and number of protected areas in Canadian jurisdictions. Biological Conservation.
#Manuscript question code identifiers: F1=Legal_9, F2=Legal_11, F3=Legal_75, F4=76, C1=12, C2=13, C3=43, C4=48-49-72, C5=58, C6=59, C7=60, C8=61


library(MASS)
library(lme4)
library(bbmle)
library(AICcmodavg)
library(ca)
library(plotrix)
library(gplots)
library(Hmisc)

rm(list=ls())


#Input PA data
Data<-read.csv("Leroux et al_PALegislationData.csv")
attach(Data)

#First, we need to subset the data into PAs established before and after their respective jurisdiction's legislation enactment
#NOTE added AA in the Before data points to force R to read this as the first record.
PA_Before <- subset(Data, TIME=="AABefore")
PA_After <- subset(Data, TIME=="After")

#Subset the data to extract only the dependent variable (PA Size) and Table of independent variables (Legal questions)
PASize <- subset(Data, select=c("AREA"))
Covars <- subset(Data, select=c("F1", "F2","F3","F4","C1","C2","C3","C4","C5","C6","C7","C8"))

###################################################################################################
#Series of Models for Ecozone + Time (Before/After) + Provision_X + Time*Provision_X interactions
###################################################################################################
#Iterate over all models for different Provision_X * Time interactions. 
#LEGAL Effect SIZE
LegalES <-NULL
LegalES <- rbind(LegalES, data.frame(Legal=c("F1", "F2","F3","F4","C1","C2","C3","C4","C5","C6","C7","C8"), Full_RSquared=sapply(1:ncol(Covars), function(i) {summary(lm(log10(PASize[,1]) ~ Data$ECOZONE + Data$TIME*Covars[,i]))$r.squared}), Reduced_RSquared=sapply(1:ncol(Covars), function(j) {summary(lm(log10(PASize[,1]) ~ Data$ECOZONE + Data$TIME + Covars[,j]))$r.squared})))
LegalES

#Add Cohen's legal to the above table
LegalES$CohenD = (LegalES$Full_RSquared - LegalES$Reduced_RSquared)/(1 - LegalES$Full_RSquared)


#################################################
#Plot effect sizes
#################################################
#Order effect sizes first for plotting
EffectSizeOrdered <- LegalES[with(LegalES, order(-CohenD)), ]

#This produces Figure 2 of the manuscript
#Make revised plot where we plot C questions in order, then F questions in order
#Make bar plot of all legal question effect sizes
par(mai=c(0.85,0.9,0.3,0.1))
barplot(c(0.0156388971,0.0100672752,0.0097509938,0.0095445018,0.0093289250,0.0017196185,0.0006384765,0.0006384765,0.0111471184,0.0093387421,0.0089165436,0.0006727087), xlab="Legal Question", ylab="Effect Size (Cohen's f^2)", ylim=c(0,0.02), cex.lab=1.5,cex.axis=1.25,names.arg=c("C6","C8","C5","C7","C4","C2","C3","C1","F3","F1","F4","F2"))

#######################################
#Print ANOVA tables for all models
#######################################
anova(lm(log10(AREA) ~ ECOZONE + TIME*F1, data=Data))
anova(lm(log10(AREA) ~ ECOZONE + TIME*F2, data=Data))
anova(lm(log10(AREA) ~ ECOZONE + TIME*F3, data=Data))
anova(lm(log10(AREA) ~ ECOZONE + TIME*F4, data=Data))
anova(lm(log10(AREA) ~ ECOZONE + TIME*C1, data=Data))
anova(lm(log10(AREA) ~ ECOZONE + TIME*C2, data=Data))
anova(lm(log10(AREA) ~ ECOZONE + TIME*C3, data=Data))
anova(lm(log10(AREA) ~ ECOZONE + TIME*C4, data=Data))
anova(lm(log10(AREA) ~ ECOZONE + TIME*C5, data=Data))
anova(lm(log10(AREA) ~ ECOZONE + TIME*C6, data=Data))
anova(lm(log10(AREA) ~ ECOZONE + TIME*C7, data=Data))
anova(lm(log10(AREA) ~ ECOZONE + TIME*C8, data=Data))
anova(lm(log10(AREA) ~ ECOZONE, data=Data))
anova(lm(log10(AREA) ~ TIME, data=Data))

########################################
#Linear model coefficients
########################################
summary(lm(log10(AREA) ~ Data$ECOZONE + Data$TIME*Data$F1))
summary(lm(log10(AREA) ~ Data$ECOZONE + Data$TIME*Data$F2))
summary(lm(log10(AREA) ~ Data$ECOZONE + Data$TIME*Data$F3))
summary(lm(log10(AREA) ~ Data$ECOZONE + Data$TIME*Data$F4))
summary(lm(log10(AREA) ~ Data$ECOZONE + Data$TIME*Data$C1))
summary(lm(log10(AREA) ~ Data$ECOZONE + Data$TIME*Data$C2))
summary(lm(log10(AREA) ~ Data$ECOZONE + Data$TIME*Data$C3))
summary(lm(log10(AREA) ~ Data$ECOZONE + Data$TIME*Data$C4))
summary(lm(log10(AREA) ~ Data$ECOZONE + Data$TIME*Data$C5))
summary(lm(log10(AREA) ~ Data$ECOZONE + Data$TIME*Data$C6))
summary(lm(log10(AREA) ~ Data$ECOZONE + Data$TIME*Data$C7))
summary(lm(log10(AREA) ~ Data$ECOZONE + Data$TIME*Data$C8))

#################################
# START OF NUMBER of PAs ANALYSIS
#################################
#############################################################################################################################
# Make a table of # of PAs after enactment and mean +/- SD # of PAs before for moving window equal to #years after enactment
#############################################################################################################################

#Subset PAs per jurisdiction so we can calculate NumPA before
AB_Before <- subset(PA_Before, JURISDICTION == "AB")
BC_Before <- subset(PA_Before, JURISDICTION == "BC")
CAN_Before <- subset(PA_Before, JURISDICTION == "CAN")
NL_Before <- subset(PA_Before, JURISDICTION == "NFL")
NU_Before <- subset(PA_Before, JURISDICTION == "NUN")
ON_Before <- subset(PA_Before, JURISDICTION == "ONT")
SK_Before <- subset(PA_Before, JURISDICTION == "SK")
YK_Before <- subset(PA_Before, JURISDICTION == "YK")

#Add a column of 1 for each record, so I can count them easily
AB_Before$count <- 1
BC_Before$count <- 1
CAN_Before$count <- 1
NL_Before$count <- 1
NU_Before$count <- 1
ON_Before$count <- 1
SK_Before$count <- 1
YK_Before$count <- 1

#For each JURISDICTION run a loop to calculate the number of PAs established before per # of years after enactment
#Alberta
AB_Sum <- NULL
#run over first year to last year (year before enactment - number of years after enactment)
for(i in seq(1932,1988,1)){
	count <- sum(AB_Before$count[AB_Before$DATE >= i & AB_Before$DATE <= i + 11])
	
	AB_Sum <- rbind(AB_Sum, data.frame(StartYear = i, Sum=count))

print(i)
}

#Create effect size distribution of #PAs after - # of PAs before
#Need to standardize the effect size by the total number of PAs
AB_Sum$EffectSize <- (11-AB_Sum$Sum)/74

#British-Columbia
BC_Sum <- NULL
#run over first year to last year (year before enactment - number of years after enactment)
for(k in seq(1911,1980,1)){
	count <- sum(BC_Before$count[BC_Before$DATE >= k & BC_Before$DATE <= k + 15])
	
	BC_Sum <- rbind(BC_Sum, data.frame(StartYear = k, Sum=count))

print(k)
}

#Create effect size distribution of #PAs after - # of PAs before
#Need to standardize the effect size by the total number of PAs
BC_Sum$EffectSize <- (356-BC_Sum$Sum)/895

#Newfoundland & Labrador
NL_Sum <- NULL
#run over first year to last year (year before enactment - number of years after enactment)
for(l in seq(1954,1964,1)){
	count <- sum(NL_Before$count[NL_Before$DATE >= l & NL_Before$DATE <= l + 23])
	
	NL_Sum <- rbind(NL_Sum, data.frame(StartYear = l, Sum=count))

print(l)
}

#Create effect size distribution of #PAs after - # of PAs before
#Need to standardize the effect size by the total number of PAs
NL_Sum$EffectSize <- (2-NL_Sum$Sum)/31

#Nunavut - HAS FEWER YEARS BEFORE THAN AFTER
NU_Sum <- NULL

#Just has one data point
NU_Sum <- rbind(NU_Sum, data.frame(StartYear = 1988, Sum=3))

#Create effect size distribution of #PAs after - # of PAs before
#Need to standardize the effect size by the total number of PAs
NU_Sum$EffectSize <- (4-NU_Sum$Sum)/7

#Ontario
ON_Sum <- NULL
#run over first year to last year (year before enactment - number of years after enactment)
for(m in seq(1893,2000,1)){
	count <- sum(ON_Before$count[ON_Before$DATE >= m & ON_Before$DATE <= m + 5])
	
	ON_Sum <- rbind(ON_Sum, data.frame(StartYear = m, Sum=count))

print(m)
}

#Create effect size distribution of #PAs after - # of PAs before
#Need to standardize the effect size by the total number of PAs
ON_Sum$EffectSize <- (25-ON_Sum$Sum)/624

#Saskatchewan
SK_Sum <- NULL
#run over first year to last year (year before enactment - number of years after enactment)
for(n in seq(1922,1960,1)){
	count <- sum(SK_Before$count[SK_Before$DATE >= n & SK_Before$DATE <= n + 25])
	
	SK_Sum <- rbind(SK_Sum, data.frame(StartYear = n, Sum=count))

print(n)
}

#Create effect size distribution of #PAs after - # of PAs before
#Need to standardize the effect size by the total number of PAs
SK_Sum$EffectSize <- (23-SK_Sum$Sum)/58

#Yukon
YK_Sum <- NULL
#run over first year to last year (year before enactment - number of years after enactment)
for(j in seq(1984,1992,1)){
	count <- sum(YK_Before$count[YK_Before$DATE >= j & YK_Before$DATE <= j + 9])
	
	YK_Sum <- rbind(YK_Sum, data.frame(StartYear = j, Sum=count))

print(j)
}

#Create effect size distribution of #PAs after - # of PAs before
#Need to standardize the effect size by the total number of PAs
YK_Sum$EffectSize <- (4-YK_Sum$Sum)/7

#Canada
CAN_Sum <- NULL
#run over first year to last year (year before enactment - number of years after enactment)
for(o in seq(1885,1988,1)){
	count <- sum(CAN_Before$count[CAN_Before$DATE >= o & CAN_Before$DATE <= o + 11])
	
	CAN_Sum <- rbind(CAN_Sum, data.frame(StartYear = o, Sum=count))

print(o)
}

#Create effect size distribution of #PAs after - # of PAs before
#Need to standardize the effect size by the total number of PAs
CAN_Sum$EffectSize <- (10-CAN_Sum$Sum)/39

#Column "after" is date of first pa established after legislation. 
#Make summary table of jurisdiction legislation enactment date, date of first PA established, number of years after legislation enactment, number of PAs after legislation enactment, mean number of PA before legislation enactment, SD of number of PA before legislation enactment, number of moving windows used and total number of PAs.
PANum <- NULL
PANum <- rbind(PANum, data.frame(Jurisdiction = c("AB", "BC", "NL","NU","ON","SK","YK","CAN"), EnactData = c(2000,1996,1988,1988,2006,1986,2002,2000), DateofFirstPA = c(1932,1911,1954,1974,1893,1922,1984,1885), NumYrsAfterEnact = c(11,15,23,23,5,25,9,11), NumPAAfterEnact = c(11,356,2,4,25,23,4,10), MeanNumPABeforeEnact = c(mean(AB_Sum$Sum),mean(BC_Sum$Sum),mean(NL_Sum$Sum),3,mean(ON_Sum$Sum),mean(SK_Sum$Sum),mean(YK_Sum$Sum),mean(CAN_Sum$Sum)), SDNumPABeforeEnact = c(sd(AB_Sum$Sum),sd(BC_Sum$Sum),sd(NL_Sum$Sum),0,sd(ON_Sum$Sum),sd(SK_Sum$Sum),sd(YK_Sum$Sum),sd(CAN_Sum$Sum)), NumMovingWindows = c(57,70,11,1,108,39,9,104), TotalNumPAs = c(74, 895, 31, 7, 624, 58, 7, 39)))

########################################################################
##############################################
### CREATE OUR OBSERVED and NULL DISTRIBUTION and fit the models
#Step 1: Draw an observed effect size, fit model ES ~ provision - do it 5000 times
#Step 2: Take same observed values drawn in Step 1 but now re-shuffle the provision answer and fit model ES ~ provision - do it 5000 times
#Step 3: Calculate difference in Observed_Coefficient - Null_Coefficient. If 95% CI does not overlap 0, it is significant
##############################################
#load library to shuffle existing provision answers
library(permute)

#Output2, EffectSize2, MODEL_Xa are for the observed data. Output, EffectSize and MODEL_X are for the null data
#Put results of null linear models here
Output <- NULL
#Put results of observed linear model here
Output2 <- NULL
#Put raw effect size (After-Before) that are used for observed model in this table
Boxy <- NULL

#Do it 5000 times
for(x in seq(1,5000,1)){
	
###########################################
#MAKE OBSERVED DATA SET AND FIT MODEL
###########################################
# Step 1a	
#Need to clear this table for every iteration
EffectSize2 <- NULL
#Variation in ES is due to variation in window sizes
EffectSize2 <- rbind(EffectSize2, data.frame(Jurisdiction = c("AB","BC","NL","NU","ON","SK","YK","CAN"), F1 = c("yes","no","no","no","yes","yes","yes","yes"), F2 = c("yes","no","no","no","yes","no","no","no"), C1 = c("none","none","none","zduty","none","none","zduty","zduty"),C2 = c("none","none","none","enabling","zduty","none","enabling","zduty"), C3 = c("no","no","no","yes","no","no","yes","yes"), C4 = c("yes","yes","no","no","yes","no","yes","no"), C5 = c("no","yes","no","yes","no","no","yes","no"), C6 = c("yes","yes","no","yes","no","no","yes","no"), C7 = c("no","yes","no","yes","no","no","yes","yes"), C8 = c("no","yes","no","no","no","no","yes","yes"), F3 = c("no","yes","yes","no","yes","no","yes","no"), F4 = c("yes","yes","no","yes","yes","no","yes","no"), ES = c((sample(AB_Sum$EffectSize, 1)), (sample(BC_Sum$EffectSize, 1)), (sample(NL_Sum$EffectSize, 1)), (sample(NU_Sum$EffectSize, 1)), (sample(ON_Sum$EffectSize, 1)), (sample(SK_Sum$EffectSize, 1)), (sample(YK_Sum$EffectSize, 1)), (sample(CAN_Sum$EffectSize, 1)))))

#Run the linear models (# PAs After - #PAs Before)/Total#PAs ~ Provision
MODEL_F1a <- lm(EffectSize2$ES ~ EffectSize2$F1)
MODEL_F2a <- lm(EffectSize2$ES ~ EffectSize2$F2)
MODEL_C1a <- lm(EffectSize2$ES ~ EffectSize2$C1)
MODEL_C2a <- lm(EffectSize2$ES ~ EffectSize2$C2)
MODEL_C3a <- lm(EffectSize2$ES ~ EffectSize2$C3)
MODEL_C4a <- lm(EffectSize2$ES ~ EffectSize2$C4)
MODEL_C5a <- lm(EffectSize2$ES ~ EffectSize2$C5)
MODEL_C6a <- lm(EffectSize2$ES ~ EffectSize2$C6)
MODEL_C7a <- lm(EffectSize2$ES ~ EffectSize2$C7)
MODEL_C8a <- lm(EffectSize2$ES ~ EffectSize2$C8)
MODEL_F3a <- lm(EffectSize2$ES ~ EffectSize2$F3)
MODEL_F4a <- lm(EffectSize2$ES ~ EffectSize2$F4)

#Extract the provision coefficient for each model iteration
Output2 <- rbind(Output2, data.frame(Iteration = x, F1a = coef(MODEL_F1a)[2], F2a = coef(MODEL_F2a)[2], C1a = coef(MODEL_C1a)[2], C2a = coef(MODEL_C2a)[3], C3a = coef(MODEL_C3a)[2], C4a = coef(MODEL_C4a)[2], C5a = coef(MODEL_C5a)[2], C6a = coef(MODEL_C6a)[2], C7a = coef(MODEL_C7a)[2], C8a = coef(MODEL_C8a)[2], F3a = coef(MODEL_F3a)[2], F4a = coef(MODEL_F4a)[2]))

#Keep the same data points so we can pass them on to re-shuffle the provision assignments and fit null models below
Boxy <- rbind(Boxy, data.frame(Iteration = x, AB = EffectSize2$ES[1], BC = EffectSize2$ES[2], NL = EffectSize2$ES[3], NU = EffectSize2$ES[4], ON = EffectSize2$ES[5], SK = EffectSize2$ES[6], YK = EffectSize2$ES[7], CAN = EffectSize2$ES[8]))

###########################################
#MAKE NULL DATA SET AND FIT MODEL
###########################################

#First establish all the true legal responses
F1 <- c("yes","no","no","no","yes","yes","yes","yes")
F2 <- c("yes","no","no","no","yes","no","no","no")
C1 <- c("none","none","none","zduty","none","none","zduty","zduty")
C2 <- c("none","none","none","enabling","zduty","none","enabling","zduty")
C3 <- c("no","no","no","yes","no","no","yes","yes")
C4 <- c("yes","yes","no","no","yes","no","yes","no")
C5 <- c("no","yes","no","yes","no","no","yes","no")
C6 <- c("yes","yes","no","yes","no","no","yes","no")
C7 <- c("no","yes","no","yes","no","no","yes","yes")
C8 <- c("no","yes","no","no","no","no","yes","yes")
F3 <- c("no","yes","yes","no","yes","no","yes","no")
F4 <- c("yes","yes","no","yes","yes","no","yes","no")

# Step 1a	
#Need to clear this table for every iteration
EffectSize <- NULL
#By making ES of Null = EffectSize2$ES, we keep same values from above. We are just re-shuffling the provision answers via sample(rep(X))
#Variation in ES is due to randomization
EffectSize <- rbind(EffectSize, data.frame(Jurisdiction = c("AB","BC","NL","NU","ON","SK","YK","CAN"), F1 = sample(rep(F1)), F2 = sample(rep(F2)), C1 = sample(rep(C1)),C2 = sample(rep(C2)), C3 = sample(rep(C3)), C4 = sample(rep(C4)), C5 = sample(rep(C5)), C6 = sample(rep(C6)), C7 = sample(rep(C7)), C8 = sample(rep(C8)), F3 = sample(rep(F3)), F4 = sample(rep(F4)), ES = EffectSize2$ES))

#Run the linear models 
MODEL_F1 <- lm(EffectSize$ES ~ EffectSize$F1)
MODEL_F2 <- lm(EffectSize$ES ~ EffectSize$F2)
MODEL_C1 <- lm(EffectSize$ES ~ EffectSize$C1)
MODEL_C2 <- lm(EffectSize$ES ~ EffectSize$C2)
MODEL_C3 <- lm(EffectSize$ES ~ EffectSize$C3)
MODEL_C4 <- lm(EffectSize$ES ~ EffectSize$C4)
MODEL_C5 <- lm(EffectSize$ES ~ EffectSize$C5)
MODEL_C6 <- lm(EffectSize$ES ~ EffectSize$C6)
MODEL_C7 <- lm(EffectSize$ES ~ EffectSize$C7)
MODEL_C8 <- lm(EffectSize$ES ~ EffectSize$C8)
MODEL_F3 <- lm(EffectSize$ES ~ EffectSize$F3)
MODEL_F4 <- lm(EffectSize$ES ~ EffectSize$F4)

#Extract model Provision coefficient 
Output <- rbind(Output, data.frame(Iteration = x, F1 = coef(MODEL_F1)[2], F2 = coef(MODEL_F2)[2], C1 = coef(MODEL_C1)[2], C2 = coef(MODEL_C2)[3], C3 = coef(MODEL_C3)[2], C4 = coef(MODEL_C4)[2], C5 = coef(MODEL_C5)[2], C6 = coef(MODEL_C6)[2], C7 = coef(MODEL_C7)[2], C8 = coef(MODEL_C8)[2], F3 = coef(MODEL_F3)[2], F4 = coef(MODEL_F4)[2]))

print (x)
}


#############################################################
# Calculate difference between Observed - Null coefficients
#############################################################
Difference <- NULL
Difference <- rbind(Difference, data.frame(Iteration = Output$Iteration, F1 = Output2$F1a - Output$F1, F2 = Output2$F2a - Output$F2, C1 = Output2$C1a - Output$C1, C2 = Output2$C2a - Output$C2, C3 = Output2$C3a - Output$C3, C4 = Output2$C4a - Output$C4, C5 = Output2$C5a - Output$C5, C6 = Output2$C6a - Output$C6, C7 = Output2$C7a - Output$C7, C8 = Output2$C8a - Output$C8, F3 = Output2$F3a - Output$F3, F4 = Output2$F4a - Output$F4))

#############################################################
# RANK Difference among coefficients - so we can plot data
#############################################################

Difference$F1_R <- rank(Difference$F1, ties.method="first")
Difference$F2_R <- rank(Difference$F2, ties.method="first")
Difference$C1_R <- rank(Difference$C1, ties.method="first")
Difference$C2_R <- rank(Difference$C2, ties.method="first")
Difference$C3_R <- rank(Difference$C3, ties.method="first")
Difference$C4_R <- rank(Difference$C4, ties.method="first")
Difference$C5_R <- rank(Difference$C5, ties.method="first")
Difference$C6_R <- rank(Difference$C6, ties.method="first")
Difference$C7_R <- rank(Difference$C7, ties.method="first")
Difference$C8_R <- rank(Difference$C8, ties.method="first")
Difference$F3_R <- rank(Difference$F3, ties.method="first")
Difference$F4_R <- rank(Difference$F4, ties.method="first")

###########################################################################
# Make table with mean DIFFERENCE and 95th percentile values of DIFFERENCE
###########################################################################
FinalOut <- NULL
FinalOut <- rbind(FinalOut, data.frame(Legal = c("F1", "F2", "C1", "C2", "C3", "C4", "C5", "C6", "C7", "C8", "F3", "F4"), Mean = c(mean(Difference$F1), mean(Difference$F2), mean(Difference$C1), mean(Difference$C2), mean(Difference$C3), mean(Difference$C4), mean(Difference$C5), mean(Difference$C6), mean(Difference$C7), mean(Difference$C8), mean(Difference$F3), mean(Difference$F4))))

#add the 125th ranked value
FinalOut$TwentyFive[1] <- subset(Difference, F1_R == 125, select = c(F1))
FinalOut$TwentyFive[2] <- subset(Difference, F2_R == 125, select = c(F2))
FinalOut$TwentyFive[3] <- subset(Difference, C1_R == 125, select = c(C1))
FinalOut$TwentyFive[4] <- subset(Difference, C2_R == 125, select = c(C2))
FinalOut$TwentyFive[5] <- subset(Difference, C3_R == 125, select = c(C3))
FinalOut$TwentyFive[6] <- subset(Difference, C4_R == 125, select = c(C4))
FinalOut$TwentyFive[7] <- subset(Difference, C5_R == 125, select = c(C5))
FinalOut$TwentyFive[8] <- subset(Difference, C6_R == 125, select = c(C6))
FinalOut$TwentyFive[9] <- subset(Difference, C7_R == 125, select = c(C7))
FinalOut$TwentyFive[10] <- subset(Difference, C8_R == 125, select = c(C8))
FinalOut$TwentyFive[11] <- subset(Difference, F3_R == 125, select = c(F3))
FinalOut$TwentyFive[12] <- subset(Difference, F4_R == 125, select = c(F4))

#add the 4875th ranked value
FinalOut$NineSeventyFive[1] <- subset(Difference, F1_R == 4875, select = c(F1))
FinalOut$NineSeventyFive[2] <- subset(Difference, F2_R == 4875, select = c(F2))
FinalOut$NineSeventyFive[3] <- subset(Difference, C1_R == 4875, select = c(C1))
FinalOut$NineSeventyFive[4] <- subset(Difference, C2_R == 4875, select = c(C2))
FinalOut$NineSeventyFive[5] <- subset(Difference, C3_R == 4875, select = c(C3))
FinalOut$NineSeventyFive[6] <- subset(Difference, C4_R == 4875, select = c(C4))
FinalOut$NineSeventyFive[7] <- subset(Difference, C5_R == 4875, select = c(C5))
FinalOut$NineSeventyFive[8] <- subset(Difference, C6_R == 4875, select = c(C6))
FinalOut$NineSeventyFive[9] <- subset(Difference, C7_R == 4875, select = c(C7))
FinalOut$NineSeventyFive[10] <- subset(Difference, C8_R == 4875, select = c(C8))
FinalOut$NineSeventyFive[11] <- subset(Difference, F3_R == 4875, select = c(F3))
FinalOut$NineSeventyFive[12] <- subset(Difference, F4_R == 4875, select = c(F4))

########################################################################################################
# Plots the difference between observed - null model provision coefficients with 95th CI values
########################################################################################################

#########################################
# Order mean response for plotting
#########################################
#Order effect sizes first for plotting
DifferenceOrdered <- FinalOut[with(FinalOut, order(-Mean)), ]

#This produces Figure 3a
par(mfrow=c(1,1))
par(mai=c(0.55,0.75,0.05,0.05))
#Legal_9
errbar(y=c(0.36781511,0.34748473,0.32739488,0.27334971,0.26956956,0.26631183,0.20221059,-0.15380943,0.26442300,0.20102282,-0.09042857,-0.10282799), x = c(1,2,3,4,5,6,7,8,9,10,11,12), yplus=c(0.7829552,0.8069971,0.7782654,0.7195915,0.7204,0.6752387,0.5929934,0.4264913,0.6369463,0.5782281,0.4716652,0.3053407), yminus=c(0,0,-0.02195278,-0.08950771,-0.09374015,-0.1298967,-0.1917879,-0.7589202,-0.1756221,-0.2352825,-0.5272539,-0.4879877), pch=19, cex=2, ylim=c(-1, 1), xlab= "Legal Question", ylab="Difference", cap = 0.05, lab = c(12,5,7))

###################################################################################
# Find mean and SE of observed effect size of legal question C7 and C8 and plot it
###################################################################################
#C7
#Yes
a <- mean(c(Boxy$BC, Boxy$NU, Boxy$YK, Boxy$CAN))
aa <- sd(c(Boxy$BC, Boxy$NU, Boxy$YK, Boxy$CAN))
#No
b <- mean(c(Boxy$AB, Boxy$NL, Boxy$ON, Boxy$SK))
bb <- sd(c(Boxy$AB, Boxy$NL, Boxy$ON, Boxy$SK))

#C8
#Yes
c <- mean(c(Boxy$BC, Boxy$YK, Boxy$CAN))
cc <- sd(c(Boxy$BC, Boxy$YK, Boxy$CAN))
#No
d <- mean(c(Boxy$AB, Boxy$NL, Boxy$NU, Boxy$ON, Boxy$SK))
dd <- sd(c(Boxy$AB, Boxy$NL, Boxy$NU, Boxy$ON, Boxy$SK))

#This produces Figure 3b
par(mfrow=c(1,1))
par(mai=c(0.55,0.75,0.05,0.05))
errbar(y=c(a,b,c,d), x = c(1,2,3,4), yplus=c(a+aa,b+bb,c+cc,d+dd), yminus=c(a-aa,b-bb,c-cc,d-dd), pch=19, cex=2, ylim=c(-0.5, 0.5), xlab= "Legal Question", ylab="Difference", cap = 0.05, lab = c(12,5,7), xlim=c(0.5,4.5))

#####################################################################################################
#Extract proportional change in average PA size for jurisdictions that have (_Y) and do not (_N) have 
#legal_X provision
#####################################################################################################
#Step 1 - extrat before and after PAs for each jurisdiction (see above)
AB_PropChange <- (median(AB_After$Shape_Area)-median(AB_Before$Shape_Area))/(median(AB_Before$Shape_Area))
BC_PropChange <- (median(BC_After$Shape_Area)-median(BC_Before$Shape_Area))/(median(BC_Before$Shape_Area))
CAN_PropChange <- (median(CAN_After$Shape_Area)-median(CAN_Before$Shape_Area))/(median(CAN_Before$Shape_Area))
NL_PropChange <- (median(NL_After$Shape_Area)-median(NL_Before$Shape_Area))/(median(NL_Before$Shape_Area))
NU_PropChange <- (median(NU_After$Shape_Area)-median(NU_Before$Shape_Area))/(median(NU_Before$Shape_Area))
ON_PropChange <- (median(ON_After$Shape_Area)-median(ON_Before$Shape_Area))/(median(ON_Before$Shape_Area))
SK_PropChange <- (median(SK_After$Shape_Area)-median(SK_Before$Shape_Area))/(median(SK_Before$Shape_Area))
YK_PropChange <- (median(YK_After$Shape_Area)-median(YK_Before$Shape_Area))/(median(YK_Before$Shape_Area))

#F1
Legal_9_Y <- c(AB_PropChange,ON_PropChange,SK_PropChange,YK_PropChange,CAN_PropChange)
Legal_9_N <- c(BC_PropChange,NL_PropChange,NU_PropChange)

mean(Legal_9_Y)
std.error(Legal_9_Y)
mean(Legal_9_N)
std.error(Legal_9_N)

#F2
Legal_11_Y <- c(AB_PropChange,ON_PropChange)
Legal_11_N <- c(BC_PropChange,NL_PropChange,NU_PropChange,SK_PropChange,YK_PropChange,CAN_PropChange)

mean(Legal_11_Y)
std.error(Legal_11_Y)
mean(Legal_11_N)
std.error(Legal_11_N)

#F3
Legal_75_Y <- c(BC_PropChange,NL_PropChange,ON_PropChange,YK_PropChange)
Legal_75_N <- c(AB_PropChange,NU_PropChange,SK_PropChange,CAN_PropChange)

mean(Legal_75_Y)
std.error(Legal_75_Y)
mean(Legal_75_N)
std.error(Legal_75_N)

#F4
Legal_76_Y <- c(AB_PropChange,BC_PropChange,NU_PropChange,ON_PropChange,YK_PropChange)
Legal_76_N <- c(NL_PropChange,SK_PropChange,CAN_PropChange)

mean(Legal_76_Y)
std.error(Legal_76_Y)
mean(Legal_76_N)
std.error(Legal_76_N)

#C1
Legal_12_Y <- c(NU_PropChange,YK_PropChange,CAN_PropChange)
Legal_12_N <- c(AB_PropChange,BC_PropChange,NL_PropChange,ON_PropChange,SK_PropChange)

mean(Legal_12_Y)
std.error(Legal_12_Y)
mean(Legal_12_N)
std.error(Legal_12_N)

#C2
Legal_13_Y <- c(NU_PropChange,ON_PropChange,YK_PropChange,CAN_PropChange)
Legal_13_N <- c(AB_PropChange,BC_PropChange,NL_PropChange,SK_PropChange)

mean(Legal_13_Y)
std.error(Legal_13_Y)
mean(Legal_13_N)
std.error(Legal_13_N)

#C3
Legal_43_Y <- c(NU_PropChange,YK_PropChange,CAN_PropChange)
Legal_43_N <- c(AB_PropChange,BC_PropChange,NL_PropChange,ON_PropChange,SK_PropChange)

mean(Legal_43_Y)
std.error(Legal_43_Y)
mean(Legal_43_N)
std.error(Legal_43_N)

#C4
Legal_484972_Y <- c(AB_PropChange,BC_PropChange,ON_PropChange,YK_PropChange)
Legal_484972_N <- c(NL_PropChange,NU_PropChange,SK_PropChange,CAN_PropChange)

mean(Legal_484972_Y)
std.error(Legal_484972_Y)
mean(Legal_484972_N)
std.error(Legal_484972_N)

#C5
Legal_58_Y <- c(BC_PropChange,NU_PropChange,YK_PropChange)
Legal_58_N <- c(AB_PropChange,NL_PropChange,ON_PropChange,SK_PropChange,CAN_PropChange)

mean(Legal_58_Y)
std.error(Legal_58_Y)
mean(Legal_58_N)
std.error(Legal_58_N)

#C6
Legal_59_Y <- c(AB_PropChange,BC_PropChange,NU_PropChange,YK_PropChange)
Legal_59_N <- c(NL_PropChange,ON_PropChange,SK_PropChange,CAN_PropChange)

mean(Legal_59_Y)
std.error(Legal_59_Y)
mean(Legal_59_N)
std.error(Legal_59_N)

#C7
Legal_60_Y <- c(BC_PropChange,NU_PropChange,YK_PropChange,CAN_PropChange)
Legal_60_N <- c(AB_PropChange,NL_PropChange,ON_PropChange,SK_PropChange)

mean(Legal_60_Y)
std.error(Legal_60_Y)
mean(Legal_60_N)
std.error(Legal_60_N)

#C8
Legal_61_Y <- c(BC_PropChange,YK_PropChange,CAN_PropChange)
Legal_61_N <- c(AB_PropChange,NL_PropChange,NU_PropChange,ON_PropChange,SK_PropChange)

mean(Legal_61_Y)
std.error(Legal_61_Y)
mean(Legal_61_N)
std.error(Legal_61_N)


######################################################
#Rate of change in PAs before/after per jurisdiction
######################################################
AB_RateB <- 0.926
AB_RateA <- 1
BC_RateB <- 6.341
BC_RateA <- 23.73
NL_RateB <- 0.85
NL_RateA <- 0.087
NU_RateB <- 0.214
NU_RateA <- 0.174
ON_RateB <- 5.301
ON_RateA <- 5
SK_RateB <- 0.547
SK_RateA <- 0.92
YK_RateB <- 0.167
YK_RateA <- 0.444
CAN_RateB <- 0.252
CAN_RateA <- 0.909

#F1
Legal_9_Y_B <- c(AB_RateB,ON_RateB,SK_RateB,YK_RateB,CAN_RateB)
Legal_9_Y_A <- c(AB_RateA,ON_RateA,SK_RateA,YK_RateA,CAN_RateA)
Legal_9_N_B <- c(BC_RateB,NL_RateB,NU_RateB)
Legal_9_N_A <- c(BC_RateA,NL_RateA,NU_RateA)

sort(Legal_9_Y_B)
sort(Legal_9_Y_A)
sort(Legal_9_N_B)
sort(Legal_9_N_A)

#F2
Legal_11_Y_B <- c(AB_RateB,ON_RateB)
Legal_11_Y_A <- c(AB_RateA,ON_RateA)
Legal_11_N_B <- c(BC_RateB,NL_RateB,NU_RateB,SK_RateB,YK_RateB,CAN_RateB)
Legal_11_N_A <- c(BC_RateA,NL_RateA,NU_RateA,SK_RateA,YK_RateA,CAN_RateA)

sort(Legal_11_Y_B)
sort(Legal_11_Y_A)
sort(Legal_11_N_B)
sort(Legal_11_N_A)

#F3
Legal_75_Y_B <- c(BC_RateB,NL_RateB,ON_RateB,YK_RateB)
Legal_75_Y_A <- c(BC_RateA,NL_RateA,ON_RateA,YK_RateA)
Legal_75_N_B <- c(AB_RateB,NU_RateB,SK_RateB,CAN_RateB)
Legal_75_N_A <- c(AB_RateA,NU_RateA,SK_RateA,CAN_RateA)

sort(Legal_75_Y_B)
sort(Legal_75_Y_A)
sort(Legal_75_N_B)
sort(Legal_75_N_A)

#F4
Legal_76_Y_B <- c(AB_RateB,BC_RateB,NU_RateB,ON_RateB,YK_RateB)
Legal_76_Y_A <- c(AB_RateA,BC_RateA,NU_RateA,ON_RateA,YK_RateA)
Legal_76_N_B <- c(NL_RateB,SK_RateB,CAN_RateB)
Legal_76_N_A <- c(NL_RateA,SK_RateA,CAN_RateA)

sort(Legal_76_Y_B)
sort(Legal_76_Y_A)
sort(Legal_76_N_B)
sort(Legal_76_N_A)

#C1
Legal_12_Y_B <- c(NU_RateB,YK_RateB,CAN_RateB)
Legal_12_Y_A <- c(NU_RateA,YK_RateA,CAN_RateA)
Legal_12_N_B <- c(AB_RateB,BC_RateB,NL_RateB,ON_RateB,SK_RateB)
Legal_12_N_A <- c(AB_RateA,BC_RateA,NL_RateA,ON_RateA,SK_RateA)

sort(Legal_12_Y_B)
sort(Legal_12_Y_A)
sort(Legal_12_N_B)
sort(Legal_12_N_A)

#C2
Legal_13_Y_B <- c(NU_RateB,ON_RateB,YK_RateB,CAN_RateB)
Legal_13_Y_A <- c(NU_RateA,ON_RateA,YK_RateA,CAN_RateA)
Legal_13_N_B <- c(AB_RateB,BC_RateB,NL_RateB,SK_RateB)
Legal_13_N_A <- c(AB_RateA,BC_RateA,NL_RateA,SK_RateA)

sort(Legal_13_Y_B)
sort(Legal_13_Y_A)
sort(Legal_13_N_B)
sort(Legal_13_N_A)

#C3
Legal_43_Y_B <- c(NU_RateB,YK_RateB,CAN_RateB)
Legal_43_Y_A <- c(NU_RateA,YK_RateA,CAN_RateA)
Legal_43_N_B <- c(AB_RateB,BC_RateB,NL_RateB,ON_RateB,SK_RateB)
Legal_43_N_A <- c(AB_RateA,BC_RateA,NL_RateA,ON_RateA,SK_RateA)

sort(Legal_43_Y_B)
sort(Legal_43_Y_A)
sort(Legal_43_N_B)
sort(Legal_43_N_A)

#C4
Legal_484972_Y_B <- c(AB_RateB,BC_RateB,ON_RateB,YK_RateB)
Legal_484972_Y_A <- c(AB_RateA,BC_RateA,ON_RateA,YK_RateA)
Legal_484972_N_B <- c(NL_RateB,NU_RateB,SK_RateB,CAN_RateB)
Legal_484972_N_A <- c(NL_RateA,NU_RateA,SK_RateA,CAN_RateA)

sort(Legal_484972_Y_B)
sort(Legal_484972_Y_A)
sort(Legal_484972_N_B)
sort(Legal_484972_N_A)

#C5
Legal_58_Y_B <- c(BC_RateB,NU_RateB,YK_RateB)
Legal_58_Y_A <- c(BC_RateA,NU_RateA,YK_RateA)
Legal_58_N_B <- c(AB_RateB,NL_RateB,ON_RateB,SK_RateB,CAN_RateB)
Legal_58_N_A <- c(AB_RateA,NL_RateA,ON_RateA,SK_RateA,CAN_RateA)

sort(Legal_58_Y_B)
sort(Legal_58_Y_A)
sort(Legal_58_N_B)
sort(Legal_58_N_A)

#C6
Legal_59_Y_B <- c(AB_RateB,BC_RateB,NU_RateB,YK_RateB)
Legal_59_Y_A <- c(AB_RateA,BC_RateA,NU_RateA,YK_RateA)
Legal_59_N_B <- c(NL_RateB,ON_RateB,SK_RateB,CAN_RateB)
Legal_59_N_A <- c(NL_RateA,ON_RateA,SK_RateA,CAN_RateA)

sort(Legal_59_Y_B)
sort(Legal_59_Y_A)
sort(Legal_59_N_B)
sort(Legal_59_N_A)

#C7
Legal_60_Y_B <- c(BC_RateB,NU_RateB,YK_RateB,CAN_RateB)
Legal_60_Y_A <- c(BC_RateA,NU_RateA,YK_RateA,CAN_RateA)
Legal_60_N_B <- c(AB_RateB,NL_RateB,ON_RateB,SK_RateB)
Legal_60_N_A <- c(AB_RateA,NL_RateA,ON_RateA,SK_RateA)

sort(Legal_60_Y_B)
sort(Legal_60_Y_A)
sort(Legal_60_N_B)
sort(Legal_60_N_A)

#C8
Legal_61_Y_B <- c(BC_RateB,YK_RateB,CAN_RateB)
Legal_61_Y_A <- c(BC_RateA,YK_RateA,CAN_RateA)
Legal_61_N_B <- c(AB_RateB,NL_RateB,NU_RateB,ON_RateB,SK_RateB)
Legal_61_N_A <- c(AB_RateA,NL_RateA,NU_RateA,ON_RateA,SK_RateA)

sort(Legal_61_Y_B)
sort(Legal_61_Y_A)
sort(Legal_61_N_B)
sort(Legal_61_N_A)

##############################################################################################
#Make some plots of PA size to visualize interaction between before/after and legal responses
#This generates Figure S2 in Appendix 2
##############################################################################################
par(mfrow=c(3,2))
par(mai=c(0.5,0.65,0.3,0.1))
#Province model - Before
#C6
boxplot(log10(Data$AREA) ~ Data$C6 + Data$TIME, ylab="", names=c("NO", "YES", "NO", "YES"), main="Legal Question C6", cex.main=1.5, cex.axis=1.5)
#F3
boxplot(log10(Data$AREA) ~ Data$F3 + Data$TIME, ylab="", names=c("NO", "YES", "NO", "YES"), main="Legal Question F3", cex.main=1.5, cex.axis=1.5)
#C8
boxplot(log10(Data$AREA) ~ Data$C8 + Data$TIME, ylab="log10(PASize) km^2", names=c("NO", "YES", "NO", "YES"), cex.lab=1.5, cex.main=1.5, cex.axis=1.5, main="Legal Question C8")
#C5
boxplot(log10(Data$AREA) ~ Data$C5 + Data$TIME, ylab="", names=c("NO", "YES", "NO", "YES"), main="Legal Question C5", cex.main=1.5, cex.axis=1.5)
#C7
boxplot(log10(Data$AREA) ~ Data$C7 + Data$TIME, ylab="", names=c("NO", "YES", "NO", "YES"), main="Legal Question C7", cex.main=1.5, cex.axis=1.5)
mtext(c("BEFORE"), side=1, line=2.5, at=c(1.5), font=2)
mtext(c("AFTER"), side=1, line=2.5, at=c(3.5), font=2)
#F1
boxplot(log10(Data$Shape_Area) ~ Data$Legal_9 + Data$Time, ylab="", names=c("NO", "YES", "NO", "YES"), main="Legal Question F1", cex.main=1.5, cex.axis=1.5)
mtext(c("BEFORE"), side=1, line=2.5, at=c(1.5), font=2)
mtext(c("AFTER"), side=1, line=2.5, at=c(3.5), font=2)

##############################################################################################
#Make some boxplots of PA size per province before/after 
#This generates Figure S1 in Appendix 2
##############################################################################################
#need to subset per province first - keep all of the data columns
AB2 <- subset(Data, JURISDICTION == "AB")
BC2 <- subset(Data, JURISDICTION == "BC")
CAN2 <- subset(Data, JURISDICTION == "CAN")
NL2 <- subset(Data, JURISDICTION == "NFL")
NU2 <- subset(Data, JURISDICTION == "NUN")
ON2 <- subset(Data, JURISDICTION == "ONT")
SK2 <- subset(Data, JURISDICTION == "SK")
YK2 <- subset(Data, JURISDICTION == "YK")

par(mfrow=c(2,4))
par(mai=c(0.5,0.65,0.3,0.1))
#Province model - Before
###################################
#AB
boxplot(log10(AB2$AREA) ~ AB2$TIME, ylab="log10(PASize) km^2", names=c("", ""), main="Alberta", cex.main=1.5, cex.axis=1.5, cex.lab=1.5)
#BC
boxplot(log10(BC2$AREA) ~ BC2$TIME, ylab="",  names=c("", ""), main="British Columbia", cex.main=1.5, cex.axis=1.5)
#NL
boxplot(log10(NL2$AREA) ~ NL2$TIME, ylab="", names=c("", ""), main="Newfoundland & Labrador", cex.main=1.5, cex.axis=1.5)
#NU
boxplot(log10(NU2$AREA) ~ NU2$TIME, ylab="", names=c("", ""), main="Nunavut", cex.main=1.5, cex.axis=1.5)
#ON
boxplot(log10(ON2$AREA) ~ ON2$TIME, ylab="log10(PASize) km^2", names=c("Before", "After"), main="Ontario", cex.main=1.5, cex.axis=1.5, cex.lab=1.5)
#SK
boxplot(log10(SK2$AREA) ~ SK2$TIME, ylab="", names=c("Before", "After"), main="Saskatchewan", cex.main=1.5, cex.axis=1.5)
#YK
boxplot(log10(YK2$AREA) ~ YK2$TIME, ylab="", names=c("Before", "After"), main="Yukon", cex.main=1.5, cex.axis=1.5)
#CAN
boxplot(log10(CAN2$AREA) ~ CAN2$TIME, ylab="",  names=c("Before", "After"), main="Canada", cex.main=1.5, cex.axis=1.5)

##############################################
#Make cumulative plots
#This code generates Figures 1 b, c
##############################################
#Extract data for each jurisdiction
AB <- subset(Data, JURISDICTION == "AB", select=c(AREA, DATE))
BC <- subset(Data, JURISDICTION == "BC", select=c(AREA, DATE))
CAN <- subset(Data, JURISDICTION == "CAN", select=c(AREA, DATE))
NL <- subset(Data, JURISDICTION == "NFL", select=c(AREA, DATE))
NU <- subset(Data, JURISDICTION == "NUN", select=c(AREA, DATE))
ON <- subset(Data, JURISDICTION == "ONT", select=c(AREA, DATE))
SK <- subset(Data, JURISDICTION == "SK", select=c(AREA, DATE))
YK <- subset(Data, JURISDICTION == "YK", select=c(AREA, DATE))

#Add a one for each protected area. We will do a row sum on this column
AB$count <-1
BC$count <-1
CAN$count <-1
NL$count <-1
NU$count <-1
ON$count <-1
SK$count <-1
YK$count <-1

#count the number of protected areas per year
AB_PA_Count <- aggregate(x = AB$count, by = list(AB$DATE), FUN = "sum")
BC_PA_Count <- aggregate(x = BC$count, by = list(BC$DATE), FUN = "sum")
CAN_PA_Count <- aggregate(x = CAN$count, by = list(CAN$DATE), FUN = "sum")
NL_PA_Count <- aggregate(x = NL$count, by = list(NL$DATE), FUN = "sum")
NU_PA_Count <- aggregate(x = NU$count, by = list(NU$DATE), FUN = "sum")
ON_PA_Count <- aggregate(x = ON$count, by = list(ON$DATE), FUN = "sum")
SK_PA_Count <- aggregate(x = SK$count, by = list(SK$DATE), FUN = "sum")
YK_PA_Count <- aggregate(x = YK$count, by = list(YK$DATE), FUN = "sum")

#area sum of protected areas per year. Data are already in km^2
AB_PA_Area <- aggregate(x = AB$AREA, by = list(AB$DATE), FUN = "sum") 
BC_PA_Area <- aggregate(x = BC$AREA, by = list(BC$DATE), FUN = "sum") 
CAN_PA_Area <- aggregate(x = CAN$AREA, by = list(CAN$DATE), FUN = "sum") 
NL_PA_Area <- aggregate(x = NL$AREA, by = list(NL$DATE), FUN = "sum") 
NU_PA_Area <- aggregate(x = NU$AREA, by = list(NU$DATE), FUN = "sum") 
ON_PA_Area <- aggregate(x = ON$AREA, by = list(ON$DATE), FUN = "sum") 
SK_PA_Area <- aggregate(x = SK$AREA, by = list(SK$DATE), FUN = "sum") 
YK_PA_Area <- aggregate(x = YK$AREA, by = list(YK$DATE), FUN = "sum") 

#Create a new data frame where we have a column for dates 1885 to 2010, which are the book ends of our year of establishment for PAs
Date <- NULL
Date <- rbind(Date, data.frame(Group.1=1885:2010))

#Merge the rowsum data on the new Date by Year -> for NUMBER OF PAS per year. Need to call it Group.1 because we are joining the data on the same column name. Aggregate creates grouping column called Group.1.
FullDataCountAB <- merge(Date, AB_PA_Count, by="Group.1", all.x=TRUE)
FullDataCountBC <- merge(Date, BC_PA_Count, by="Group.1", all.x=TRUE)
FullDataCountCAN <- merge(Date, CAN_PA_Count, by="Group.1", all.x=TRUE)
FullDataCountNL <- merge(Date, NL_PA_Count, by="Group.1", all.x=TRUE)
FullDataCountNU <- merge(Date, NU_PA_Count, by="Group.1", all.x=TRUE)
FullDataCountON <- merge(Date, ON_PA_Count, by="Group.1", all.x=TRUE)
FullDataCountSK <- merge(Date, SK_PA_Count, by="Group.1", all.x=TRUE)
FullDataCountYK <- merge(Date, YK_PA_Count, by="Group.1", all.x=TRUE)

#replace NA with 0
FullDataCountAB[is.na(FullDataCountAB)]<-0
FullDataCountBC[is.na(FullDataCountBC)]<-0
FullDataCountCAN[is.na(FullDataCountCAN)]<-0
FullDataCountNL[is.na(FullDataCountNL)]<-0
FullDataCountNU[is.na(FullDataCountNU)]<-0
FullDataCountON[is.na(FullDataCountON)]<-0
FullDataCountSK[is.na(FullDataCountSK)]<-0
FullDataCountYK[is.na(FullDataCountYK)]<-0

#calculate cumulative sum
FullDataCountAB$CumSum <- cumsum(FullDataCountAB$x)
FullDataCountBC$CumSum <- cumsum(FullDataCountBC$x)
FullDataCountCAN$CumSum <- cumsum(FullDataCountCAN$x)
FullDataCountNL$CumSum <- cumsum(FullDataCountNL$x)
FullDataCountNU$CumSum <- cumsum(FullDataCountNU$x)
FullDataCountON$CumSum <- cumsum(FullDataCountON$x)
FullDataCountSK$CumSum <- cumsum(FullDataCountSK$x)
FullDataCountYK$CumSum <- cumsum(FullDataCountYK$x)

#Now, do the same for cumulative area
FullDataAreaAB <- merge(Date, AB_PA_Area, by="Group.1", all.x=TRUE)
FullDataAreaBC <- merge(Date, BC_PA_Area, by="Group.1", all.x=TRUE)
FullDataAreaCAN <- merge(Date, CAN_PA_Area, by="Group.1", all.x=TRUE)
FullDataAreaNL <- merge(Date, NL_PA_Area, by="Group.1", all.x=TRUE)
FullDataAreaNU <- merge(Date, NU_PA_Area, by="Group.1", all.x=TRUE)
FullDataAreaON <- merge(Date, ON_PA_Area, by="Group.1", all.x=TRUE)
FullDataAreaSK <- merge(Date, SK_PA_Area, by="Group.1", all.x=TRUE)
FullDataAreaYK <- merge(Date, YK_PA_Area, by="Group.1", all.x=TRUE)

#replace NA with 0
FullDataAreaAB[is.na(FullDataAreaAB)]<-0
FullDataAreaBC[is.na(FullDataAreaBC)]<-0
FullDataAreaCAN[is.na(FullDataAreaCAN)]<-0
FullDataAreaNL[is.na(FullDataAreaNL)]<-0
FullDataAreaNU[is.na(FullDataAreaNU)]<-0
FullDataAreaON[is.na(FullDataAreaON)]<-0
FullDataAreaSK[is.na(FullDataAreaSK)]<-0
FullDataAreaYK[is.na(FullDataAreaYK)]<-0

#calculate cumulative sum
FullDataAreaAB$CumSum <- cumsum(FullDataAreaAB$x)
FullDataAreaBC$CumSum <- cumsum(FullDataAreaBC$x)
FullDataAreaCAN$CumSum <- cumsum(FullDataAreaCAN$x)
FullDataAreaNL$CumSum <- cumsum(FullDataAreaNL$x)
FullDataAreaNU$CumSum <- cumsum(FullDataAreaNU$x)
FullDataAreaON$CumSum <- cumsum(FullDataAreaON$x)
FullDataAreaSK$CumSum <- cumsum(FullDataAreaSK$x)
FullDataAreaYK$CumSum <- cumsum(FullDataAreaYK$x)


#Make plots
op=par(mfrow=c(1,2),lwd=2,bty="l")
par(mai=c(0.9,0.9,0.3,0.1))
plot(FullDataCountAB$Group.1, log(FullDataCountAB$CumSum+0.001), ylim=c(-0.5,7), ylab="ln(cumulative number of protected areas)", xlab="year",cex.lab=1.25, cex.axis=1.25, lwd=0.8, pch=0, cex=1.5)
#axis.break(2,200,style="zigzag")
points(FullDataCountBC$Group.1, log(FullDataCountBC$CumSum+0.001), pch=1, lwd=0.8, cex=1.5)
points(FullDataCountCAN$Group.1, log(FullDataCountCAN$CumSum+0.001), pch=2, lwd=0.8, cex=1.5)
#points(FullDataCountNB$Group.1, log(FullDataCountNB$CumSum+0.001), pch=3, lwd=1, cex=1.5)
points(FullDataCountNL$Group.1, log(FullDataCountNL$CumSum+0.001), pch=3, lwd=0.8, cex=1.5)
points(FullDataCountNU$Group.1, log(FullDataCountNU$CumSum+0.001), pch=4, lwd=0.8, cex=1.5)
points(FullDataCountON$Group.1, log(FullDataCountON$CumSum+0.001), pch=5, lwd=0.8, cex=1.5)
points(FullDataCountSK$Group.1, log(FullDataCountSK$CumSum+0.001), pch=6, lwd=0.8, cex=1.5)
points(FullDataCountYK$Group.1, log(FullDataCountYK$CumSum+0.001), pch=8, lwd=0.8, cex=1.5)
#Let's add a legend to the above plot
legend("topleft", legend=c("AB","BC","CAN","NL","NU","ON","SK","YK"), pch=c(0,1,2,3,4,5,6,8), pt.cex=2, lwd=1)

plot(FullDataAreaAB$Group.1, log10(FullDataAreaAB$CumSum+0.001), ylim=c(-0.5,6), ylab="log10(cumulative number of protected areas)", xlab="year",cex.lab=1.25, cex.axis=1.25, lwd=0.8, pch=0, cex=1.5)
points(FullDataAreaBC$Group.1, log10(FullDataAreaBC$CumSum+0.001), pch=1, lwd=0.8, cex=1.5)
points(FullDataAreaCAN$Group.1, log10(FullDataAreaCAN$CumSum+0.001), pch=2, lwd=0.8, cex=1.5)
#points(FullDataAreaNB$Group.1, log10(FullDataAreaNB$CumSum+0.001), col="darkgrey", lwd=1, cex=1.5)
points(FullDataAreaNL$Group.1, log10(FullDataAreaNL$CumSum+0.001), pch=3, lwd=0.8, cex=1.5)
points(FullDataAreaNU$Group.1, log10(FullDataAreaNU$CumSum+0.001), pch=4, lwd=0.8, cex=1.5)
points(FullDataAreaON$Group.1, log10(FullDataAreaON$CumSum+0.001), pch=5, lwd=0.8, cex=1.5)
points(FullDataAreaSK$Group.1, log10(FullDataAreaSK$CumSum+0.001), pch=6, lwd=0.8, cex=1.5)
points(FullDataAreaYK$Group.1, log10(FullDataAreaYK$CumSum+0.001), pch=7, lwd=0.8, cex=1.5)

